@@ -23,8 +23,12 @@ class Dish(object):
         self.raw = raw
         self.recipe = recipe
     
-    def apply(self, recipe):
+    def apply(self, recipe, arg=None):
         r = self.recipe.copy()
+
+        if arg:
+            recipe = recipe(arg)
+
         r.append(recipe)
         return Dish(recipe.cook(self.raw), recipe=r)
     
@@ -34,4 +38,6 @@ class Dish(object):
     def __add__(self, x):
         return Dish(self.raw + x, recipe=self.recipe)
     def __radd__(self, x):
-        return Dish(x + self.raw, recipe=self.recipe)
\ No newline at end of file
+        return Dish(x + self.raw, recipe=self.recipe)
+    def __eq__(self, x):
+        return self.raw == getattr(x, "raw", x)
\ No newline at end of file
